/*
 * Copyright (c) 2023 - 2024. KeyWare.Co.Ltd All rights reserved.
 * 项目名称：C++ 信息安全性设计准则
 * 项目描述：用于检查C++源代码的安全性设计准则的Sonarqube插件
 * 版权说明：本软件属北京关键科技股份有限公司所有，在未获得北京关键科技股份有限公司正式授权情况下，任何企业和个人，不能获取、阅读、安装、传播本软件涉及的任何受知识产权保护的内容。
 */
package com.keyware.sonar.cxx;

import org.junit.jupiter.api.Test;
import org.sonar.api.config.internal.MapSettings;

import static org.assertj.core.api.Assertions.assertThat;

class CxxLanguageTest {

  private final MapSettings settings = new MapSettings();

  @Test
  void testCxxLanguageStringConfiguration() throws Exception {
    var language = new CxxLanguage(settings.asConfig());
    assertThat(language.getKey()).isEqualTo("cxx");
  }

  @Test
  void shouldReturnConfiguredFileSuffixes() {
    settings.setProperty(CxxLanguage.FILE_SUFFIXES_KEY, ".C,.c,.H,.h");
    var cxx = new CxxLanguage(settings.asConfig());
    String[] expected = {".C", ".c", ".H", ".h"};
    assertThat(cxx.getFileSuffixes()).contains(expected);
  }

  @Test
  void shouldReturnDefaultFileSuffixes1() {
    var cxx = new CxxLanguage(settings.asConfig());
    String[] expected = {"disabled"};
    assertThat(cxx.getFileSuffixes()).contains(expected);
  }

  @Test
  void shouldReturnDefaultFileSuffixes2() {
    settings.setProperty(CxxLanguage.FILE_SUFFIXES_KEY, "");
    var cxx = new CxxLanguage(settings.asConfig());
    String[] expected = {"disabled"};
    assertThat(cxx.getFileSuffixes()).contains(expected);
  }

  @Test
  void shouldBeDisabled() {
    settings.setProperty(CxxLanguage.FILE_SUFFIXES_KEY, "-");
    var cxx = new CxxLanguage(settings.asConfig());
    String[] expected = {"disabled"};
    assertThat(cxx.getFileSuffixes()).contains(expected);
  }

}
